@@ -16,7 +16,7 @@
 
 """Package init."""
 
-from __future__ import absolute_import, unicode_literals
+from __future__ import absolute_import, print_function, unicode_literals
 
 __metaclass__ = type
 __all__ = [
@@ -31,7 +31,7 @@ __all__ = [
     ]
 
 
-__version__ = '1.1.1'
+__version__ = '1.2'
 
 
 from ._hash import make_secret
